GeoArrowArrayReader

Trait GeoArrowArrayReader 

pub trait GeoArrowArrayReader: Iterator<Item = GeoArrowResult<Arc<dyn GeoArrowArray>>> {
    // Required method
    fn data_type(&self) -> GeoArrowType;
}
Trait for types that can read Arc<dyn GeoArrowArray>’s.

This is similar to an upstream RecordBatchReader, but for GeoArrow arrays instead of RecordBatches.

This will always yield an Arc<dyn GeoArrowArray> with the same GeoArrowType, which is known in advance (see Self::data_type).

To create from an iterator, see GeoArrowArrayIterator.

Required Methods

fn data_type(&self) -> GeoArrowType

Returns the field of this GeoArrowArrayReader.

Implementation of this trait should guarantee that all Arc<dyn GeoArrowArray>’s returned by this reader should have the same GeoArrowType as returned from this method.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl<R: GeoArrowArrayReader + ?Sized> GeoArrowArrayReader for Box<R>

Implementors