pub fn from_wkb<'a, A: GenericWkbArrayType<'a>>(
arr: &'a A,
to_type: GeoArrowType,
) -> GeoArrowResult<Arc<dyn GeoArrowArray>>Expand description
Parse a GenericWkbArray or WkbViewArray to a GeoArrowArray with the designated
GeoArrowType.
Note that the GeoArrow metadata on the new array is taken from to_type not the original
array. Ensure you construct the GeoArrowType with the correct metadata.
Note that this will be slow if converting from a WKB array to another WKB-typed array. If
possible, use the From impls on WKB-typed arrays.